﻿// SimpleVideoGameCaseExample Version 1 - Using Papervision 2.0 Beta - Revision 876, BulkLoader - Revision 251
// A very simple demo of how to create an Xbox 360 3D video game case
//
// released under MIT License
// http://www.opensource.org/licenses/mit-license.php
//
//@author		Devin Reimer
//@version		1.0.0
//@website 		http://blog.almostlogical.com, http://www.permaven.com


//Copyright (c) 2009 Devin Reimer

/*
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package com 
{
	import br.com.stimuli.loading.BulkProgressEvent;
	import flash.display.Bitmap;
	import flash.display.BitmapData;
	import flash.display.Sprite;
	import flash.events.Event;
	import flash.geom.Rectangle;
	import org.papervision3d.view.BasicView;
	import org.papervision3d.objects.primitives.Cube;
	import org.papervision3d.materials.utils.MaterialsList;
	import org.papervision3d.materials.BitmapMaterial;
	import org.papervision3d.materials.MovieMaterial;
	
	import br.com.stimuli.loading.BulkLoader;
	
	public class Main extends Sprite
	{
		private static const STANDARD_COVER_PATH:String = "Images/StandardCover/";
		private static const BACK_COVER_OVERLAY_FILE_PATH:String = STANDARD_COVER_PATH + "BackCover.png";
		private static const COVER_OVERLAY_FILE_PATH:String = STANDARD_COVER_PATH + "Cover.png";
		private static const SPINE_OVERLAY_FILE_PATH:String = STANDARD_COVER_PATH + "Spine.png";
		private static const OPEN_END_IMAGE_FILE_PATH:String = STANDARD_COVER_PATH + "OpenEnd.jpg";
		private static const TOP_AND_BOTTOM_IMAGE_FILE_PATH:String = STANDARD_COVER_PATH + "TopAndBottom.jpg";
		
		//add your own case scans here (Scan dimensions are 325 x 218)
		private static const VIDEO_GAME_CASE_IMAGE_FILE_PATH:String = "Images/Covers/GenericCover.jpg";  
		
		private static const CASE_WIDTH:int = 158;
		private static const CASE_DEPTH:int = 17;
		private static const CASE_HEIGHT:int = 226;
			
		private var view:BasicView;
		private var videoCaseMainCube:Cube;
		private var mainBulkLoader:BulkLoader;
		
		public function Main() 
		{
			view = new BasicView(stage.stageWidth, stage.stageHeight);
			
			loadAssets();
			
			view.camera.z += 650;
			
			addChild(view);
		}
		
		private function beginRender():void
		{
			addEventListener(Event.ENTER_FRAME, loop);
		}
		
		private function loadAssets():void
		{
			mainBulkLoader = new BulkLoader("MainBulkLoader");
			mainBulkLoader.add(BACK_COVER_OVERLAY_FILE_PATH);
			mainBulkLoader.add(COVER_OVERLAY_FILE_PATH);
			mainBulkLoader.add(SPINE_OVERLAY_FILE_PATH);
			mainBulkLoader.add(OPEN_END_IMAGE_FILE_PATH);
			mainBulkLoader.add(TOP_AND_BOTTOM_IMAGE_FILE_PATH);
			mainBulkLoader.add(VIDEO_GAME_CASE_IMAGE_FILE_PATH);
			mainBulkLoader.addEventListener(BulkProgressEvent.COMPLETE,loadAssetsComplete);
			mainBulkLoader.start();
		}
		
		private function loadAssetsComplete(evt:Event):void
		{
			createScene();
		}
		
		private function createScene():void
		{
			videoCaseMainCube = createVideoCase();
			view.scene.addChild(videoCaseMainCube);
			beginRender();
		}
		
		private function createVideoCase():Cube
		{
			var videoCaseCube:Cube;
			var coverSprite:Sprite = createSpriteCover();
			var videoCaseMaterials:MaterialsList = new MaterialsList();
			
			videoCaseMaterials.addMaterial(new MovieMaterial(coverSprite, false, false, true, new Rectangle(0, 0, CASE_WIDTH, CASE_HEIGHT)),"back");
			videoCaseMaterials.addMaterial(new MovieMaterial(coverSprite, false, false, true, new Rectangle(CASE_WIDTH, 0, CASE_DEPTH, CASE_HEIGHT)),"right");
			videoCaseMaterials.addMaterial(new MovieMaterial(coverSprite, false, false, true, new Rectangle(CASE_WIDTH + CASE_DEPTH, 0, CASE_WIDTH, CASE_HEIGHT)),"front");
			
			videoCaseMaterials.addMaterial(new BitmapMaterial(mainBulkLoader.getBitmapData(OPEN_END_IMAGE_FILE_PATH),true), "left");
			videoCaseMaterials.addMaterial(new BitmapMaterial(mainBulkLoader.getBitmapData(TOP_AND_BOTTOM_IMAGE_FILE_PATH),true), "top");
			videoCaseMaterials.addMaterial(new BitmapMaterial(mainBulkLoader.getBitmapData(TOP_AND_BOTTOM_IMAGE_FILE_PATH),true), "bottom");
			
			videoCaseCube = new Cube(videoCaseMaterials, CASE_WIDTH, CASE_DEPTH, CASE_HEIGHT, 6, 6, 6);
			
			videoCaseCube.rotationY = 180;
			
			return videoCaseCube;
		}
		
		private function createSpriteCover():Sprite
		{
			var fullCoverSprite:Sprite = new Sprite();
			var backCoverBitmap:Bitmap;
			var spineBitmap:Bitmap;
			var frontCoverBitmap:Bitmap;
			var scanCoverBitmap:Bitmap;
			var buffer:int = 4;
		
			backCoverBitmap = mainBulkLoader.getBitmap(BACK_COVER_OVERLAY_FILE_PATH);
			spineBitmap = mainBulkLoader.getBitmap(SPINE_OVERLAY_FILE_PATH);
			frontCoverBitmap = mainBulkLoader.getBitmap(COVER_OVERLAY_FILE_PATH);
			scanCoverBitmap = mainBulkLoader.getBitmap(VIDEO_GAME_CASE_IMAGE_FILE_PATH);
			
			spineBitmap.x = CASE_WIDTH;
			frontCoverBitmap.x = CASE_WIDTH + CASE_DEPTH;
			
			scanCoverBitmap.x = buffer
			scanCoverBitmap.y = buffer;
			
			fullCoverSprite.addChild(scanCoverBitmap);
			fullCoverSprite.addChild(spineBitmap);
			fullCoverSprite.addChild(frontCoverBitmap);	
			fullCoverSprite.addChild(backCoverBitmap);
			
			
			return fullCoverSprite;
		}
		
		private function loop(evt:Event):void
		{
			videoCaseMainCube.rotationY++;
			view.singleRender();
		}
		
	}
	
}